/**
  *  \file client/dialogs/teamedit.cc
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/teamedit.h"
#include "client/widgets/racelist.h"
#include "client/widgets/teamname.h"
#include "client/widgets/teamgrid.h"
#include "cpluslib/holder.h"
#include "cpluslib/format.h"
#include "game/struct.h"
#include "game/team.h"
#include "gfx/palette.h"
#include "ui/layout.h"
#include "ui/window.h"
#include "util/nls.h"
#include "game/global.h"
#include "ui/widgets/inputline.h"
#include "ui/widgets/button.h"
#include "ui/uiglobal.h"
#include "client/widgets/helpwidget.h"

namespace {
    class WTeamEditWindow : public UIWindow {
        ObjectHolder holder;
        WTeamGrid team_grid;
        WTeamName team_name;

        void buildDialog();
        void onCursorMove();
        void onEditName();
        void onOK();
        void onCancel();

     public:
        WTeamEditWindow();
        ~WTeamEditWindow();
    };
}

WTeamEditWindow::WTeamEditWindow()
    : UIWindow(_("Teams"), BLUE_WINDOW, COLOR_GRAY)
{
    buildDialog();
}

WTeamEditWindow::~WTeamEditWindow()
{ }

void
WTeamEditWindow::buildDialog()
{
    // WTeamEditWindow[UIVBoxLayout]
    //   UIGroup[UIGridLayout]
    //     UISpacer  WRaceList
    //     WRaceList WTeamGrid
    //   UIGroup[UIHBoxLayout]
    //     WTeamName UIButton
    //   UIGroup[UIHBoxLayout]
    //     UIButton "OK"
    //     UIButton "Cancel"
    //     UISpacer
    setLayout(UIVBoxLayout::instance5);

    UIGroup& g1 = holder.add(new UIGroup(holder.add(new UIGridLayout(2))));
    g1.add(holder.add(new UISpacer()));
    g1.add(holder.add(new WRaceList(0, WRaceList::HorizontalLayout | WRaceList::ShowLetters   | WRaceList::NoColors, 1, NUM_PLAYERS)));
    g1.add(holder.add(new WRaceList(0, WRaceList::VerticalLayout   | WRaceList::ShowRaceNames | WRaceList::NoColors, 1, NUM_PLAYERS)));
    g1.add(team_grid);
    add(g1);

    UIGroup& g2 = holder.add(new UIGroup(UIHBoxLayout::instance5));
    g2.add(team_name);
    g2.add(holder.add(new UIButton(0, "N", 'n')).addCall(this, &WTeamEditWindow::onEditName));
    add(g2);

    UIGroup& g3 = holder.add(new UIGroup(UIHBoxLayout::instance5));
    g3.add(holder.add(new UIButton(0, _("OK"),     SDLK_RETURN)).addCall(this, &WTeamEditWindow::onOK));
    g3.add(holder.add(new UIButton(0, _("Cancel"), SDLK_ESCAPE)).addCall(this, &WTeamEditWindow::onCancel));
    g3.add(holder.add(new UISpacer()));
    g3.add(holder.add(new UIButton(_("Help"), 'h')));
    add(g3);
    add(holder.add(new WHelpWidget("pcc2:teams")));

    pack();

    team_grid.sig_pos_changed.add(this, &WTeamEditWindow::onCursorMove);
    onCursorMove();
}

void
WTeamEditWindow::onCursorMove()
{
    team_name.setTeam(team_grid.getCursorTeam());
}

void
WTeamEditWindow::onEditName()
{
    // Prepare team name
    int teamNr = team_grid.getCursorTeam();
    string_t teamName;
    if (isNamedTeam(teamNr))
        teamName = getTeamName(teamNr);

    // Edit it
    if (UIInputLine::run(teamName, 200, format(_("Team %d"), teamNr), _("Team Name:"), 30, UIInputLine::ilf_GameChars))
        setTeamName(teamNr, teamName);
}

void
WTeamEditWindow::onOK()
{
    team_grid.saveToGlobals();
    stop(1);
}

void
WTeamEditWindow::onCancel()
{
    stop(0);
}

void
editTeams()
{
    WTeamEditWindow w;
    ui_root->centerWidget(w);
    ui_root->runModal(w);
    getDisplayedTurn().recomputeOrbitFlags();
}
