/**
  *  \file game/cargotype.cc
  *  \brief Cargo Types
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/cargotype.h"
#include "game/spec.h"
#include "util/nls.h"

/** Get user-visible name of cargo item /type/. */
string_t
getCargoName(GCargoType type)
{
    static const char* const names[el_Torps] = {
        N_("Neutronium"),
        N_("Tritanium"),
        N_("Duranium"),
        N_("Molybdenum"),
        N_("Fighters"),
        N_("Colonists"),
        N_("Supplies"),
        N_("Money")
    };
    if (type < el_Torps)
        return string_t(_(names[type]));
    else
        return ::getTorp(getTorpTypeFromCargoType(type)).getName();
}

/** Get unit of cargo type /type/.
    \returns name of unit, or empty string if type doesn't have
    a unit (i.e. torps) */
string_t
getCargoUnit(GCargoType type)
{
    switch(type) {
     case el_Colonists:
        return string_t(_("Clans"));
     case el_Neutronium:
     case el_Duranium:
     case el_Tritanium:
     case el_Molybdenum:
     case el_Supplies:
        return string_t("kt");  // I guess we better don't translate that
     case el_Money:
        return string_t("mc");  // same here
     default:
        return string_t();
    }
}
