/**
  *  \file int/intglobal.h
  *  \brief Interpreter: Global Definitions
  *
  *  This module contains global name definitions (symbol tables)
  *  and values (user-defined properties, variables).
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_INTGLOBAL_H
#define PCC_V2_INT_INTGLOBAL_H

#include "cpluslib/ptrvector.h"

class IntVariableNames;
class IntDataSegment;
class IntContext;
class IntExecutionContext;
class IntArgBlock;
class IntValue;

extern IntVariableNames planet_property_names;
extern IntVariableNames ship_property_names;
extern IntVariableNames global_property_names;
extern IntDataSegment global_values;
extern ptr_vector<IntContext> global_contexts;

/** Temporary context. Manages lifetime for contexts temporarily added
    to global_contexts. Upon construction, remembers how many contexts
    are active. Upon destruction, removes all that were added in the
    meantime. */
class IntTemporaryContextLock {
    ptr_vector<IntContext>::size_type size;
 public:
    IntTemporaryContextLock();
    ~IntTemporaryContextLock();
};

// Planet Properties
enum {
    pp_Comment = 0
};
// Ship Properties
enum {
    sp_Comment = 0
};

extern const struct ModuleInitializer mod_int[];

IntDataSegment& getShipProperties(int sid);
IntDataSegment& getPlanetProperties(int pid);

void defineGlobalProcedure(const char* name, void proc(IntExecutionContext& exc, IntArgBlock& args));
void defineGlobalValue(const char* name, IntValue* value);

#endif
