/**
  *  \file int/subr.cc
  *  \brief Interpreter: Subroutine Value
  *
  *  This used to be in int/compound.cc, but has been moved into a separate
  *  module to reduce link dependencies. c2talk, c2mailout get 300k smaller
  *  when this is separate.
  */

#include "int/compound.h"
#include "int/vmio.h"
#include "int/interror.h"

/*************************** IntSubroutineValue **************************/

IntSubroutineValue::IntSubroutineValue(IntBCORef bco)
    : bco(bco)
{ }

IntSubroutineValue::~IntSubroutineValue()
{ }

IntBCORef
IntSubroutineValue::getBytecodeObject()
{
    return bco;
}

string_t
IntSubroutineValue::toString(bool /*readable*/)
{
    string_t name = bco->getName();
    string_t result = "#<subr";
    if (name.size()) {
        result += ":";
        result += name;
    }
    return result + ">";
}

void
IntSubroutineValue::store(IntTagNode& tag, Stream& /*aux*/)
{
    IntVMSaveContext* vsc = IntVMSaveContext::getCurrentInstance();
    if (vsc != 0) {
        tag.tag   = IntTagNode::Tag_BCO;
        tag.value = vsc->addBCO(*bco);
    } else {
        throw IntError::notSerializable();
    }
}

IntSubroutineValue*
IntSubroutineValue::clone()
{
    return new IntSubroutineValue(bco);
}
