/**
  *  \file tests/testoutx.cc
  *  \brief TEST: Clipping of UTF-8 text
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <stdio.h>
#include "arch/platform.h"
#include "cpluslib/utf8.h"
#include "gfx/bmfont.h"
#include "gfx/font.h"
#include "gfx/init.h"
#include "gfx/palette.h"
#include "ui/event.h"
#include "util/modinit.h"
#include "io/streams.h"

int main(int argc, char** argv)
{
    if (argc != 2) {
        printf("usage: %s fontfile.fnt\n", argv[0]);
        return 1;
    }

    // Initialize
    performInitialisation(OnStartup, mod_base_gui);

    // Load the font
    GfxBitmapFont f;
    argv = Platform::convertArgumentsToUtf8(argv);
    try {
        f.load(*Stream::openFile(argv[1], Stream::C_READ), 0);
    }
    catch (std::exception& e) {
        printf("%s\n", e.what());
        return 1;
    }

    // Graphics
    SDL_Surface* sfc = initGraphics(0, 0);
    initPalette(sfc);
    GfxSurface screen(sfc, true);
    screen.lock();
    const int sx = screen.getSize().x;
    const int sy = screen.getSize().y;

    // Generate a string
    string_t s;
    appendUtf8(s, 'i');
    appendUtf8(s, 0x174);  /* LATIN CAPITAL LETTER W WITH ROOF */
    appendUtf8(s, 'i');

    GfxContext ctx;
    ctx.useCanvas(screen);
    ctx.useFont(f);
    ctx.useColorScheme(GfxStandardColorScheme::instance);
    ctx.setColor(COLOR_WHITE);

    // Display this string
    int x = 0;
    int y = 0;
    int line = f.getHeight();
    for (int width = 0; width < 100; ++width) {
        // Display one item
        drawSolidBar(ctx, GfxRect(x, y, width, line), COLOR_RED);
        outTextF(ctx, x, y, width, s);

        // Find next position
        if (y + line > sy) {
            y = 0;
            x += 100;
            if (x + 100 > sx)
                break;
        } else {
            y += line + 5;
        }
    }
    screen.unlock();
    screen.update(GfxRect(screen));

    // Wait
    UIEvent e;
    do
        getEvent(e);
    while (e.type != ev_Key || getClassOfKey(e.key.code) == KeyModifier);
    return 0;
}
